# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: order.proto
# Protobuf Python Version: 5.27.2
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    27,
    2,
    '',
    'order.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0border.proto\x12\x07oi.papi\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"i\n\x04Item\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08scene_id\x18\x02 \x01(\t\x12\x13\n\x0btarget_geom\x18\x03 \x01(\x0c\x12.\n\ritem_metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xc2\x02\n\x05Order\x12\n\n\x02id\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x1c\n\x05items\x18\x03 \x03(\x0b\x32\r.oi.papi.Item\x12\x19\n\x11product_spec_name\x18\x04 \x01(\t\x12\"\n\x05state\x18\x05 \x01(\x0e\x32\x13.oi.papi.OrderState\x12\x0f\n\x07\x64\x65tails\x18\x06 \x01(\t\x12\x0b\n\x03url\x18\x07 \x01(\t\x12)\n\x08metadata\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07\x63reator\x18\t \x01(\t\x12.\n\ncreated_on\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_on\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xaa\x01\n\x10OrderListRequest\x12\"\n\x05state\x18\x01 \x01(\x0e\x32\x13.oi.papi.OrderState\x12\x17\n\x0f\x64\x61ta_source_ids\x18\x02 \x03(\t\x12\x14\n\x0cprovider_ids\x18\x03 \x03(\t\x12 \n\x18\x61nalysis_computation_ids\x18\x04 \x03(\t\x12!\n\x19\x61lgorithm_computation_ids\x18\x05 \x03(\t\"H\n\x11OrderListResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1e\n\x06orders\x18\x02 \x03(\x0b\x32\x0e.oi.papi.Order\"\x1d\n\x0fOrderGetRequest\x12\n\n\x02id\x18\x01 \x01(\t\"F\n\x10OrderGetResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1d\n\x05order\x18\x02 \x01(\x0b\x32\x0e.oi.papi.Order\"!\n\x13OrderApproveRequest\x12\n\n\x02id\x18\x01 \x01(\t\"+\n\x14OrderApproveResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\"\x90\x01\n\x12OrderCreateRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x19\n\x11product_spec_name\x18\x02 \x01(\t\x12)\n\x08metadata\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1c\n\x05items\x18\x04 \x03(\x0b\x32\r.oi.papi.Item\"I\n\x13OrderCreateResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r\x12\x1d\n\x05order\x18\x02 \x01(\x0b\x32\x0e.oi.papi.Order\" \n\x12OrderCancelRequest\x12\n\n\x02id\x18\x01 \x01(\t\"*\n\x13OrderCancelResponse\x12\x13\n\x0bstatus_code\x18\x01 \x01(\r*\xac\x01\n\nOrderState\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07\x43REATED\x10\x01\x12\x0c\n\x08\x41PPROVED\x10\x02\x12\n\n\x06QUEUED\x10\x03\x12\x0e\n\nPROCESSING\x10\x04\x12\x0b\n\x07ORDERED\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\r\n\tDELIVERED\x10\x07\x12\n\n\x06\x46\x41ILED\x10\x08\x12\x14\n\x10PENDING_APPROVAL\x10\t\x12\r\n\tSUBMITTED\x10\n2\xd7\x02\n\x08OrderApi\x12=\n\x04list\x12\x19.oi.papi.OrderListRequest\x1a\x1a.oi.papi.OrderListResponse\x12:\n\x03get\x12\x18.oi.papi.OrderGetRequest\x1a\x19.oi.papi.OrderGetResponse\x12\x43\n\x06\x63reate\x12\x1b.oi.papi.OrderCreateRequest\x1a\x1c.oi.papi.OrderCreateResponse\x12\x46\n\x07\x61pprove\x12\x1c.oi.papi.OrderApproveRequest\x1a\x1d.oi.papi.OrderApproveResponse\x12\x43\n\x06\x63\x61ncel\x12\x1b.oi.papi.OrderCancelRequest\x1a\x1c.oi.papi.OrderCancelResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'order_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ORDERSTATE']._serialized_start=1250
  _globals['_ORDERSTATE']._serialized_end=1422
  _globals['_ITEM']._serialized_start=87
  _globals['_ITEM']._serialized_end=192
  _globals['_ORDER']._serialized_start=195
  _globals['_ORDER']._serialized_end=517
  _globals['_ORDERLISTREQUEST']._serialized_start=520
  _globals['_ORDERLISTREQUEST']._serialized_end=690
  _globals['_ORDERLISTRESPONSE']._serialized_start=692
  _globals['_ORDERLISTRESPONSE']._serialized_end=764
  _globals['_ORDERGETREQUEST']._serialized_start=766
  _globals['_ORDERGETREQUEST']._serialized_end=795
  _globals['_ORDERGETRESPONSE']._serialized_start=797
  _globals['_ORDERGETRESPONSE']._serialized_end=867
  _globals['_ORDERAPPROVEREQUEST']._serialized_start=869
  _globals['_ORDERAPPROVEREQUEST']._serialized_end=902
  _globals['_ORDERAPPROVERESPONSE']._serialized_start=904
  _globals['_ORDERAPPROVERESPONSE']._serialized_end=947
  _globals['_ORDERCREATEREQUEST']._serialized_start=950
  _globals['_ORDERCREATEREQUEST']._serialized_end=1094
  _globals['_ORDERCREATERESPONSE']._serialized_start=1096
  _globals['_ORDERCREATERESPONSE']._serialized_end=1169
  _globals['_ORDERCANCELREQUEST']._serialized_start=1171
  _globals['_ORDERCANCELREQUEST']._serialized_end=1203
  _globals['_ORDERCANCELRESPONSE']._serialized_start=1205
  _globals['_ORDERCANCELRESPONSE']._serialized_end=1247
  _globals['_ORDERAPI']._serialized_start=1425
  _globals['_ORDERAPI']._serialized_end=1768
# @@protoc_insertion_point(module_scope)
